@@ -23,7 +23,7 @@ from . import s_log , s_db
 
 def cleanup( ) :
     #pass
-    s_db.db_filepath_delete( )
+    s_db.fdelete( )
     #s_log.write( "cleanup" )
 
 #####################################################################
