@@ -14,8 +14,10 @@
 #####################################################################
 
 import os
+import sys
 import json
 import time
+#import datetime
 import hashlib
 import sqlite3
 
@@ -23,14 +25,15 @@ from . import s_log , s_config , s_util
 
 #####################################################################
 
-db_filepath = False
-db_dirty = False
+filepath = False
 db_con = False
 
 #####################################################################
 
 def commitclose( ) :
+    
     global db_con
+
     if( db_con != False ) :
         db_con.commit( )
         db_con.close( )
@@ -38,53 +41,89 @@ def commitclose( ) :
 
 def setup( ) :
 
-    # Must be done to avoid losing rev count - see express call where this setup is called
-    rev = 1
-    if( db_con_check( ) ) :
-        rev = sys_read( "rev" ) 
+    global filepath
+
+    #s_log.write(sys.argv)
+    #if(len(sys.argv)==3 and sys.argv[0]=="_sapi.py"):
+    #    filepath=sys.argv[1]
+    #    db_con_setup( )
+    #    s_log.write("db filepath " + filepath)
+    #    return
 
     ################################################################
 
-    commitclose( )
+    if( filepath != False ) :
+        flush( )
+        return( True )
 
-    db_filepath_setup( )
+    s_log.write( "db setup" )
 
-    if( os.path.isfile( db_filepath ) ) :
-        os.remove( db_filepath )
+    ################################################################
+
+    filepath_setup( )
+
+    ################################################################
 
     db_con_setup( )
 
+    ################################################################
+
+    if( not os.path.isfile( filepath ) ) :
+        s_log.write( "False filepath isfile" ) 
+        return( False )
+
+    ################################################################
+
     init_schema( )
+    init_data( )
+    
+    ################################################################
 
-    if( os.path.isfile( db_filepath ) ) :
-        sys_update( "rev" , rev )
-        #s_log.write("REV setup " + str( rev ) )
-        return( True )
+    return( True )
 
-    s_log.write( "False db_filepath isfile" ) 
+def flush( ) :
 
-    return( False )
+    table_truncate( "files" ) 
+    table_truncate( "env" ) 
+    table_truncate( "stdio" ) 
+    table_truncate( "args" ) 
+    table_truncate( "stacks" ) 
+    table_truncate( "meta" ) 
+    table_truncate( "templates" ) 
 
 
-def db_filepath_delete( ) :
+def init_data( ) :
+# FIXME TODO add host environment vars e.g. hostname/machine id etc.
+    sys_create( "ver_db" , "1.0" )
+    #sys_create( "ver_sapi" , s_config.get_key( "/config/version" ) )
+    sys_create( "serial" , "ODS042e1919c5bd8f41cd8e1a2b8e455dd8f6fb00df0c3916d1137047a7aafc4c42" )
+    sys_create( "motto" , "HORAS NON NUMERO NISI SERENAS" )
+    sys_create( "rev" , 1 )
+    #sys_create( "sys_platform" , sys.platform )
+    #sys_create( "sys_version" , sys.version )
+    sys_create( "traceid" , s_log.get_traceid( ) )
+    #sys_create( "time_isoformat" , s_util.time_getisoformat( ) )
+    sys_create( "tcreate" , time.time( ) )
+
+def fdelete( ) :
 
     commitclose( )
 
-    if( os.path.isfile( db_filepath ) ) :
-        os.remove( db_filepath )
+    if( os.path.isfile( filepath ) ) :
+        os.remove( filepath )
 
 def file_contents( ) :
 
     commitclose( )
 
-    if not os.path.isfile( db_filepath ) :
-        s_log.write( db_filepath + " NOT exists!" )
+    if not os.path.isfile( filepath ) :
+        s_log.write( filepath + " NOT exists!" )
         return( False )
 
-    with open( db_filepath , mode = "rb" ) as file : 
+    with open( filepath , mode = "rb" ) as file : 
         db_filecontents = file.read( )
 
-    reconnect( )
+    db_con_setup( )
 
     return( db_filecontents )
 
@@ -109,10 +148,10 @@ def rewrite( payload ) :
     if( len( payload ) == 0 ) :
         s_log.write( "ERROR payload empty??")
 
-    with open( db_filepath , "wb" ) as file:
+    with open( filepath , "wb" ) as file:
         file.write( payload )
 
-    reconnect( )
+    db_con_setup( )
 
     ################################################################
 
@@ -120,27 +159,22 @@ def rewrite( payload ) :
     ver_db = sys_read( "ver_db" )
 
     if( ver_sapi != s_config.get_key( "/config/version" ) ) :
-        s_log.write( "WARNING,VER_SAPI MISMATCH," + ver_sapi + "!=" + s_config.get_key( "/config/version" ) + "," + ver_db )
+        #s_log.write( "WARNING,VER_SAPI MISMATCH," + ver_sapi + "!=" + s_config.get_key( "/config/version" ) + "," + ver_db )
+        s_log.write( "WARNING, VERSION MISMATCH," )
 
 
     #sys_update("rev",rev)
     #s_log.write("REV rewrite "+str(rev))
 
-def reconnect( ) :
-
-    commitclose( )
-
-    db_con_setup( )
-
 def db_con_setup( ) :
 
     global db_con
 
     if( db_con != False ) : return
 
-    db_con = sqlite3.connect( db_filepath_get( ) )
+    db_con = sqlite3.connect( filepath )
     #db_con.row_factory = sqlite3.Row
-    db_con.row_factory = lambda C, R: { c[0]: R[i] for i, c in enumerate(C.description) }
+    db_con.row_factory = lambda C , R : { c[ 0 ] : R[ i ] for i , c in enumerate( C.description ) }
 
     #s_log.write( "OK db_con_setup" )
 
@@ -154,26 +188,24 @@ def db_con_check( ) :
 
 #####################################################################
 
-def db_filepath_setup( ) :
 
-    global db_filepath
+def filepath_get( ) :
+    return( filepath )
 
-    if( db_filepath != False ) :
+def filepath_setup( ) :
+
+    global filepath
+
+    if( filepath != False ) :
         return
 
+    ################################################################
+
     dbworkspacedir = os.path.join( s_config.get_key( "sys/workspacedir" , "/tmp/sapiadapter" ) + "/db" , "" )
 
     os.makedirs( dbworkspacedir , exist_ok = True )
 
-    db_filepath = dbworkspacedir + s_config.get_key( "/config/session" ) + ".db" 
-
-def db_filepath_get( ) :
-    return( db_filepath )
-
-#####################################################################
-
-def db_dirty_get( ) :
-    return( db_dirty )
+    filepath = dbworkspacedir + s_config.get_key( "/config/session" ) + ".db" 
 
 #####################################################################
 
@@ -229,14 +261,6 @@ def init_schema( ) :
     sql_execute( "CREATE TABLE sys ( sn text UNIQUE , sv text )" )
     sql_execute( "CREATE INDEX index_sys ON sys ( sn )" )
 
-# FIXME TODO add host environment vars e.g. hostname/machine id etc.
-    sys_create( "ver_db" , "1.0" )
-    sys_create( "ver_sapi" , s_config.get_key( "/config/version" ) )
-    sys_create( "serial" , "ODS042e1919c5bd8f41cd8e1a2b8e455dd8f6fb00df0c3916d1137047a7aafc4c42" )
-    sys_create( "motto" , "HORAS NON NUMERO NISI SERENAS" )
-    sys_create( "rev" , 1 )
-    sys_create( "tcreate" , time.time( ) )
-
     ################################################################
 
     sql_execute( "CREATE TABLE files ( fp text UNIQUE , fc blob , fs integer , fh text )" )
@@ -274,7 +298,6 @@ def init_schema( ) :
 
 #####################################################################
 
-
 def sys_create( sn , sv_in ) :
 
     sv = s_util.json_encode( sv_in )
@@ -422,6 +445,9 @@ def env_deleteall( ) :
 
 def meta_create( mn , mv_in ) :
 
+    # FIXME TODO something better?
+    meta_delete( mn )
+
     mv = s_util.json_encode( mv_in )
 
     sql = "INSERT INTO meta ( mn , mv ) VALUES ( ? , ? )"
@@ -467,6 +493,7 @@ def meta_createorupdate( mn , mv ) :
     else :
         meta_create( mn , mv )
 
+
 ####################################################################
 
 def args_create( av ) :
@@ -606,11 +633,11 @@ def files_readall( ) :
     rows = table_readall( "files" )
     return( rows )
 
-# def files_update !!!
+# FIXME TODO def files_update !!!
 # Delete current path and create a new one?!?!?!
 def files_update( fp ) :
     files_delete( fp ) 
-    files_create( fp ) 
+    return( files_create( fp ) )
 
 def files_delete( fp ) :
 
@@ -650,6 +677,7 @@ def files_write( fp ) :
 
 
 ########################
+'''
 def files_defmeta_set( data ) :
 
     files_delete( "./local_defmeta_5800b137d.json" )
@@ -693,6 +721,7 @@ def files_defdata_get( ) :
 
 def files_defdata_write( ) :
     files_write( "./local_defdata_5800b137d.json" )
+'''
 
 ####################################################################
 
