@@ -387,21 +387,21 @@ def sleep( t = 1 ) :
     time.sleep(t) 
 
 
-def datetime_now_db( td_minutes = 0 ) :
+def datetime_now_db( td = 0 ) :
 
-    d = datetime.now( ) + timedelta(minutes=td_minutes)
+    d = datetime.now( ) + timedelta( seconds = td)
 
     return(d.strftime('%Y-%m-%d %H:%M:%S'))
 
-def datetime_timedelta_db( dbdtstr , td_minutes ) :
-    d = datetime.strptime(dbdtstr, '%Y-%m-%d %H:%M:%S') + timedelta(minutes=td_minutes)
+def datetime_timedelta_db( dbdtstr , td ) :
+    d = datetime.strptime(dbdtstr, '%Y-%m-%d %H:%M:%S') + timedelta(seconds=td)
     return(d.strftime('%Y-%m-%d %H:%M:%S'))
 
-def datetime_inrange_db( dbdt1 , dbdt2 , td_minutes ) :
+def datetime_inrange_db( dbdt1 , dbdt2 , td) :
     d1 = datetime.strptime(dbdt1, '%Y-%m-%d %H:%M:%S')  
     d2 = datetime.strptime(dbdt2, '%Y-%m-%d %H:%M:%S') 
 
     dtdiff=d2-d1
-    dtdiff_minutes=int(dtdiff.total_seconds()/60)
-    return(dtdiff_minutes<=td_minutes)
+    dtdiff_seconds=int(dtdiff.total_seconds())
+    return(dtdiff_seconds<=td)
 
